Crate cloudbbq[−][src]
Structs
| BBQDevice | A Bluetooth BBQ thermometer device which is connected. |
| RealTimeData | A data point from a BBQ device, giving the temperature of all connected probes. |
Enums
| Error | An error communicating with a BBQ thermometer device. |
| SettingResult | A response to some command sent to the device, or a notification. |
| TemperatureUnit | The temperature unit which the thermometer uses for its display. |
Functions
| find_devices | Return all compatible BBQ thermometer devices currently known by the system. |