pub struct RealTimeData {
pub probe_temperatures: Vec<Option<f32>>,
}Expand description
A data point from a BBQ device, giving the temperature of all connected probes.
Fields
probe_temperatures: Vec<Option<f32>>The current temperature of each probe in degrees Celcius, or None if the probe is disconnected.